@@ -18,7 +18,7 @@
 /* global EnigGetWindowOptions: false, EnigConfirm: false, EnigGetString: false, GetEnigmailSvc: false */
 /* global EnigLongAlert: false, EnigAlert: false, EnigInitCommon: false, ENIG_ACCOUNT_MANAGER_CONTRACTID: false */
 /* global EnigGetPref: false, EnigSetPref: false, EnigSavePrefs: false, EnigFilePicker: false, EnigGetFilePath: false */
-/* global EnigCreateRevokeCert: false */
+/* global EnigmailWindows: false, EnigCreateRevokeCert: false */
 
 // Initialize enigmailCommon
 EnigInitCommon("enigmailKeygen");
@@ -139,6 +139,8 @@ function enigmailKeygenTerminate(exitCode) {
 
       EnigSavePrefs();
 
+      EnigmailWindows.keyManReloadKeys();
+
       if (EnigConfirm(EnigGetString("keygenComplete", curId.email) + "\n\n" + EnigGetString("revokeCertRecommended"), EnigGetString("keyMan.button.generateCert"))) {
         EnigCreateRevokeCert(gGeneratedKey, curId.email, closeAndReset);
       }
@@ -258,6 +260,11 @@ function enigmailCheckPassphrase() {
     EnigAlert(EnigGetString("passSpaceProblem"));
     return null;
   }
+
+  if (passphrase.length < 8) {
+    EnigAlert(EnigGetString("passphrase.min8keys"));
+    return null;
+  }
   return passphrase;
 }
 
@@ -287,15 +294,19 @@ function enigmailKeygenStart() {
   var passphrase;
   // gpg >= 2.1 queries passphrase using gpg-agent only
   if (EnigmailGpg.getGpgFeature("keygen-passphrase")) {
-    passphrase = enigmailCheckPassphrase();
-    if (!passphrase) return;
-
     var noPassphraseElement = document.getElementById("noPassphrase");
+    var passphraseElement = document.getElementById("passphrase");
 
-    if (!passphrase && !noPassphraseElement.checked) {
-      EnigAlert(EnigGetString("passCheckBox"));
-      return;
+    if (!noPassphraseElement.checked) {
+      if (passphraseElement.value.trim() === "") {
+        EnigAlert(EnigGetString("passCheckBox"));
+        return;
+      }
+
+      passphrase = enigmailCheckPassphrase();
+      if (!passphrase) return;
     }
+
   }
   else {
     passphrase = "";
