@@ -29,6 +29,7 @@ Components.utils.import("resource://enigmail/keyRing.jsm"); /*global EnigmailKey
 Components.utils.import("resource://enigmail/uris.jsm"); /*global EnigmailURIs: false */
 Components.utils.import("resource://enigmail/constants.jsm"); /*global EnigmailConstants: false */
 Components.utils.import("resource://enigmail/data.jsm"); /*global EnigmailData: false */
+Components.utils.import("resource://enigmail/clipboard.jsm"); /*global EnigmailClipboard: false */
 
 if (!Enigmail) var Enigmail = {};
 
@@ -704,8 +705,7 @@ Enigmail.hdrView = {
 
   copyStatusInfo: function() {
     if (Enigmail.msg.securityInfo) {
-      var clipHelper = Components.classes["@mozilla.org/widget/clipboardhelper;1"].createInstance(Components.interfaces.nsIClipboardHelper);
-      clipHelper.copyString(Enigmail.msg.securityInfo.statusInfo);
+      EnigmailClipboard.setClipboardContent(Enigmail.msg.securityInfo.statusInfo);
     }
 
   },
@@ -764,7 +764,7 @@ Enigmail.hdrView = {
   msgHdrViewUnhide: function(event) {
     EnigmailLog.DEBUG("enigmailMsgHdrViewOverlay.js: this.msgHdrViewUnhide:\n");
 
-    if (Enigmail.msg.securityInfo.statusFlags !== 0) {
+    if (Enigmail.msg.securityInfo && Enigmail.msg.securityInfo.statusFlags !== 0) {
       this.enigmailBox.removeAttribute("collapsed");
     }
   },
@@ -881,7 +881,7 @@ Enigmail.hdrView = {
   updateMsgDb: function() {
     EnigmailLog.DEBUG("enigmailMsgHdrViewOverlay.js: this.updateMsgDb\n");
     var msg = gFolderDisplay.selectedMessage;
-    if (!msg) return;
+    if (!msg || !msg.folder) return;
 
     var msgHdr = msg.folder.GetMessageHeader(msg.messageKey);
     if (this.statusBar.getAttribute("encrypted") == "ok")
@@ -997,14 +997,18 @@ if (messageHeaderSink) {
         catch (ex) {
           EnigmailLog.DEBUG("enigmailMsgHdrViewOverlay.js: EnigMimeHeaderSink.isCurrentMessage: could not determine URL\n");
           url.value = {
+            host: "invalid",
+            path: "/message",
+            scheme: "enigmail",
             spec: "enigmail://invalid/message"
           };
         }
 
         EnigmailLog.DEBUG("enigmailMsgHdrViewOverlay.js: EnigMimeHeaderSink.isCurrentMessage: url=" + url.value.spec + "\n");
 
-        if (!uriSpec || uriSpec.search(/^enigmail:/) === 0 || (uriSpec.indexOf(url.value.spec) === 0 &&
-            uriSpec.substr(url.value.spec.length).search(/([\?&].*)?$/) === 0)) {
+        if (!uriSpec || uriSpec.search(/^enigmail:/) === 0 ||
+          (uri.host == url.value.host &&
+            uri.path.substr(url.value.path.length).search(/([\?&].*)?$/) === 0)) {
           return true;
         }
 
